pub enum AbilityStoneFamily {
Economy,
Cadence,
Delivery,
Magnitude,
Critical,
Shape,
Coverage,
Targeting,
Replay,
Duration,
Conversion,
Defense,
}Expand description
Twelve exclusion families. Two supports of the SAME family may not sit in one Imprint (the two sockets of one side of one ability).
Variants
Economy
Cadence
Delivery
Magnitude
Critical
Shape
Coverage
Targeting
Replay
Duration
Conversion
Defense