pub struct AbilityStoneDrop {
pub stone_id: AbilityStoneId,
pub copies: i64,
pub is_new: bool,
}Expand description
One granted stone copy, for the client drop popup and quest progression.
Fields
stone_id: AbilityStoneIdcopies: i64Copies granted by this drop.
is_new: boolThe player owned no copy of this stone before the drop.