pub struct AbilityStoneTemplate {
pub id: AbilityStoneId,
pub name: I18nString,
pub description: I18nString,
pub family: AbilityStoneFamily,
pub compatibility: AbilityStoneCompatibility,
pub ops: Vec<AbilityStoneOp>,
pub power_q_first_rank: f64,
pub power_q_max_rank: f64,
pub icon_path: String,
}Expand description
One ability stone in the catalog. Ability stones are their OWN collection — they never mix with item stones or artifact stones and cannot be socketed into their sockets.
Fields
id: AbilityStoneIdname: I18nStringdescription: I18nStringfamily: AbilityStoneFamilycompatibility: AbilityStoneCompatibilityops: Vec<AbilityStoneOp>power_q_first_rank: f64power_q_max_rank: f64icon_path: StringTrait Implementations
Sourceimpl Clone for AbilityStoneTemplate
impl Clone for AbilityStoneTemplate
Sourcefn clone(&self) -> AbilityStoneTemplate
fn clone(&self) -> AbilityStoneTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AbilityStoneTemplate
impl Debug for AbilityStoneTemplate
Sourceimpl<'de> Deserialize<'de> for AbilityStoneTemplate
impl<'de> Deserialize<'de> for AbilityStoneTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AbilityStoneTemplate
impl JsonSchema for AbilityStoneTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AbilityStoneTemplate
impl PartialEq for AbilityStoneTemplate
Sourceimpl Serialize for AbilityStoneTemplate
impl Serialize for AbilityStoneTemplate
Sourceimpl Tsify for AbilityStoneTemplate
impl Tsify for AbilityStoneTemplate
const DECL: &'static str = "/**\n * One ability stone in the catalog. Ability stones are their OWN collection \u{2014}\n * they never mix with item stones or artifact stones and cannot be socketed\n * into their sockets.\n */\nexport interface AbilityStoneTemplate {\n id: AbilityStoneId;\n name: I18nString;\n description: I18nString;\n family: AbilityStoneFamily;\n compatibility: AbilityStoneCompatibility;\n ops: AbilityStoneOp[];\n power_q_first_rank: number;\n power_q_max_rank: number;\n icon_path: string;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl StructuralPartialEq for AbilityStoneTemplate